@@ -2,10 +2,12 @@
 
 from __future__ import unicode_literals, print_function, with_statement
 
-__version__ = '6.0.1'
-__author__ = 'Santiago Debus - Grow HQ, Inc.'
+__version__ = '6.0.4'
+__author__ = 'Santiago Debus - Buzon, Inc.'
 __license__ = 'MIT'
+# v
 
 from .zipfly import ZipFly
+from .zipfly import LargePredictionSize
 from .response import FileResponse
 from .api import Buffer
