@@ -1,11 +1,19 @@
 # -*- coding: utf-8 -*-
+__version__ = '6.0.4'
+# v
 
 import io
 import stat
 import zipfile
-__version__ = '6.0.1'
 
-class ZipflyStream( io.RawIOBase ):
+ZIP64_LIMIT = (1 << 31) + 1
+
+class LargePredictionSize(Exception):
+    """
+    Raised when Buffer is larger than ZIP64
+    """
+
+class ZipflyStream(io.RawIOBase):
 
     """
     The RawIOBase ABC extends IOBase. It deals with
@@ -41,7 +49,7 @@ class ZipFly:
     def __init__(self,
                  mode = 'w',
                  paths = [],
-                 chunksize = 0x4000,
+                 chunksize = 0x8000,
                  compression = zipfile.ZIP_STORED,
                  allowZip64 = True,
                  compresslevel = None,
@@ -64,19 +72,23 @@ class ZipFly:
         if compresslevel not in (None, ):
             raise RuntimeError("Not compression level supported")
 
+        if isinstance(chunksize, str):
+            chunksize = int(chunksize, 16)
+
+
 
         self.comment = f'Written using Zipfly v{__version__}'
         self.mode = mode
         self.paths = paths
         self.filesystem = filesystem
         self.arcname = arcname
-        self.chunksize = int(chunksize)
         self.compression = compression
+        self.chunksize = chunksize
         self.allowZip64 = allowZip64
         self.compresslevel = compresslevel
         self.storesize = storesize
         self.encode = encode
-        self.ezs = 0x8e # empty zip size in bytes
+        self.ezs = int('0x8e', 16) # empty zip size in bytes
 
     def set_comment(self, comment):
 
@@ -113,70 +125,55 @@ class ZipFly:
 
     def buffer_prediction_size(self):
 
-        '''
-        BufferPredictionSize.
-        :var    hexadecimal     LIZO:     Initial length for one file
-        :var    hexadecimal     LIZM:     Initial length for multiples files (null for one file)
-        :var    hexadecimal     COMM:     Comment length in bytes set to 26 bytes (magic number)
+        if not self.allowZip64:
+            raise RuntimeError("ZIP64 extensions required")
 
-        Initialize a Buffer
-        :arg    integer     pfbs:           Buffer variable to return
-        :arg    integer     storesize:      Initial storesize
-        :arg    bytes       comment:        Buffer comment zip file
 
-        getting bytes from character in UTF-8 format
-        example:
-            1) 'a' has 1 byte in utf-8 format ( b'a' )
-            2) 'ñ' has 2 bytes in utf-8 format ( b'\xc3\xb1' )
-            3) '传' has 3 bytes in utf-8 format ( b'\xe4\xbc\xa0' )
-        '''
+        # End of Central Directory Record
+        EOCD = int('0x16', 16)
+        FILE_OFFSET = int('0x5e', 16) * len(self.paths)
 
-        # initial values
-        _len = len( self.paths )
-        _len_utf8 = int( 0x2 ) * _len
-
-        LIZO = int( 0x8e ) * _len
-        LIZM = int( 0x30 ) * ( _len - 1 )
-
-        # comment
         tmp_comment = self.comment
         if isinstance(self.comment, bytes):
             tmp_comment = ( self.comment ).decode()
 
-        COMM = int( 0x1a )
-        tmp_s = 0
-        for c in tmp_comment:
-            tmp_s += len( c.encode(self.encode) )
-        COMM = tmp_s - COMM
+        size_comment = len(tmp_comment.encode( self.encode ))
 
-        # files names
-        bt = 0
-        for path in self.paths:
-            tmp_bt = 0
+        # path-name
 
+        size_paths = 0
+        #for path in self.paths:
+        for idx in range(len(self.paths)):
+
+            '''
+            getting bytes from character in UTF-8 format
+            example:
+            '传' has 3 bytes in utf-8 format ( b'\xe4\xbc\xa0' )
+            '''
+
+            #path = paths[idx]
             name = self.arcname
-            if not self.arcname in path:
+            if not self.arcname in self.paths[idx]:
                 name = self.filesystem
 
-            tmp_name = path[name]
+            tmp_name = self.paths[idx][name]
             if (tmp_name)[0] in ('/', ):
+
                 # is dir then trunk
                 tmp_name = (tmp_name)[ 1 : len( tmp_name ) ]
 
-            for c in tmp_name:
-                tmp_bt += len( c.encode(self.encode) ) * int( 0x2 )
+            size_paths += (len(tmp_name.encode( self.encode )) - int( '0x1', 16)) * int('0x2', 16)
 
-            bt += tmp_bt
+        # zipsize
+        zs = sum([EOCD,FILE_OFFSET,size_comment,size_paths,self.storesize,])
 
-        # current process size
-        pfbs = (
-            bt + COMM + self.storesize
-        )
+        if zs > ZIP64_LIMIT:
+            raise LargePredictionSize(
+                "Prediction size for zip file greater than 2 GB not supported"
+            )
+
+        return zs
 
-        # simple arithmetic
-        return int(
-            LIZO - LIZM + pfbs -  _len_utf8
-        )
 
     def generator(self):
 
@@ -215,14 +212,10 @@ class ZipFly:
 
                 with open( path[self.filesystem], 'rb' ) as e:
                     # Read from filesystem:
-
                     with zf.open( z_info, mode = self.mode ) as d:
 
                         for chunk in iter( lambda: e.read( self.chunksize ), b'' ):
 
-                            # (e.read( ... )) this get a small chunk of the file
-                            # and return a callback to the next iterator
-
                             d.write( chunk )
                             yield stream.get()
 
@@ -230,7 +223,6 @@ class ZipFly:
             self.set_comment(self.comment)
             zf.comment = self.comment
 
-        # last chunk
         yield stream.get()
 
         # (TESTING)
